#include <stdio.h>
#include <stdlib.h>
#include <string.h>

void
die(char *msg) {
	fprintf(stderr, "%s\n", msg);
	exit(1);
}

char
mirror_char(char *key, char c) {
	while (key[0] && key[1]) {
		if (c == key[0])
			return key[1];
		if (c == key[1])
			return key[0];
		key += 2;
	}
	return c;
}

#define TEMPLATE_MAXHEIGHT 20
#define TEMPLATE_MAXWIDTH 20

int 
template_height,
template_width;
char
template[TEMPLATE_MAXHEIGHT][TEMPLATE_MAXWIDTH];
int
num_copies,
copy_mode;
char
mirrored[TEMPLATE_MAXHEIGHT][TEMPLATE_MAXWIDTH];

void
read_template(void) {
	char line[TEMPLATE_MAXWIDTH + 5];
	int r;
	for (r = 0; r < template_height; r++) {
		if (!fgets(line, TEMPLATE_MAXWIDTH + 5, stdin))
			die("eof or error reading template line");
		if (template_width != strlen(line) - 1) 
			die("template line length wrong");
		memcpy(template[r], line, template_width);
	}
}

void
mirror_template(void) {
	int r, c;
	for (r = 0; r < template_height; r++) {
		for (c = 0; c < template_width; c++)
			mirrored[r][c] = mirror_char("()<>[]\\/", template[r][template_width - c - 1]);
	}
}

void
output(void) {
	int row, copy;
	char *p; int l;
	for (row = 0; row < template_height; row++) {
		for (copy = 0; copy < num_copies; copy++) {
			if (0 == copy % 2 || 0 == copy_mode) {
				p = template[row]; l = template_width;
			} else if (2 == copy_mode) {
				p = mirrored[row] + 1; l = template_width - 1;
			} else {
				p = mirrored[row]; l = template_width;
			}
			fwrite(p, l, 1, stdout);
		}
		putchar('\n');
	}
}

int
main(void) {
	char line[500];
	if (!fgets(line, sizeof(line), stdin))
		die("error reading parameters");
	if (4 != sscanf(line, "%d%d%d%d", 
		&template_height, &template_width, &num_copies, &copy_mode
	))
		die("error parsing parameters");
	if (
		TEMPLATE_MAXHEIGHT < template_height || template_height < 0 ||
		TEMPLATE_MAXWIDTH < template_width || template_width < 0 ||
		2 < copy_mode || copy_mode < 0
	)
		die("invalid parameters");
	read_template();
	mirror_template();
	output();
	return 0;
}
